==> applyx-0.2.22-py3-none-any.whl: applyx/entrypoint/workspace/project/account/services.py <==
# coding=utf-8

import datetime

from mongoengine import Q

from applyx.service import BaseService
from project.apps.models import User


class UserService(BaseService):
    def create(self, user_dict):
        user = User()

        user.email = user_dict["email"]
        user.username = user_dict["username"]
        user.password = user_dict["password"]
        user.status = 2

        now = datetime.datetime.now()
        user.created_at = now
        user.updated_at = now

        user.switch_db("default").save()
        return user

    def filter(self, criteria, pn=0, ps=20):
        users = User.objects

        keyword = criteria.get("keyword")
        if keyword:
            query = Q(email__icontains=keyword) | Q(username__icontains=keyword)
            users = users.filter(query)

        total = users.count()
        start, end = (pn - 1) * ps, pn * ps
        users = users.order_by("-created_at")[start:end]
        return total, users

    def get(self, user_id):
        user = User.objects.filter(id=user_id).first()
        return user

    def activate(self, user_id):
        user = User.objects.filter(id=user_id)
        if user is None:
            return False

        user.status = 1

        now = datetime.datetime.now()
        user.updated_at = now

        user.switch_db("default").save()
        return True

    def update(self, user_id, user_dict):
        user = User.objects.filter(id=user_id).first()
        if user is None:
            return False

        user.email = user_dict["email"]
        user.username = user_dict["username"]

        now = datetime.datetime.now()
        user.updated_at = now

        user.switch_db("default").save()
        return True

==> applyx-0.2.30-py3-none-any.whl: applyx/entrypoint/workspace/project/account/services.py <==
# coding=utf-8

import datetime

from mongoengine import Q

from applyx.service import BaseService
from project.apps.models import User


class UserService(BaseService):
    def create(self, user_dict):
        user = User()

        user.email = user_dict['email']
        user.username = user_dict['username']
        user.password = user_dict['password']
        user.status = 2

        now = datetime.datetime.now()
        user.created_at = now
        user.updated_at = now

        user.switch_db('default').save()
        return user

    def filter(self, criteria, pn=0, ps=20):
        users = User.objects

        keyword = criteria.get('keyword')
        if keyword:
            query = Q(email__icontains=keyword) | Q(username__icontains=keyword)
            users = users.filter(query)

        total = users.count()
        start, end = (pn - 1) * ps, pn * ps
        users = users.order_by('-created_at')[start:end]
        return total, users

    def get(self, user_id):
        user = User.objects.filter(id=user_id).first()
        return user

    def activate(self, user_id):
        user = User.objects.filter(id=user_id)
        if user is None:
            return False

        user.status = 1

        now = datetime.datetime.now()
        user.updated_at = now

        user.switch_db('default').save()
        return True

    def update(self, user_id, user_dict):
        user = User.objects.filter(id=user_id).first()
        if user is None:
            return False

        user.email = user_dict['email']
        user.username = user_dict['username']

        now = datetime.datetime.now()
        user.updated_at = now

        user.switch_db('default').save()
        return True
